% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fit_and_reporting.R
\name{umxSummaryACEcov}
\alias{umxSummaryACEcov}
\alias{umxSummary.MxModelACEcov}
\title{Present results of a twin ACE-model with covariates in table and graphical forms.}
\usage{
umxSummaryACEcov(
  model,
  digits = 2,
  showRg = FALSE,
  std = TRUE,
  comparison = NULL,
  CIs = TRUE,
  zero.print = ".",
  report = c("markdown", "html"),
  file = getOption("umx_auto_plot"),
  returnStd = FALSE,
  extended = FALSE,
  ...
)
}
\arguments{
\item{model}{A \code{\link[=umxACEcov]{umxACEcov()}} model to summarize}

\item{digits}{Round to how many digits (default = 2)}

\item{showRg}{= Whether to show the genetic correlations (FALSE)}

\item{std}{= Whether to show the standardized model (TRUE)}

\item{comparison}{You can run mxCompare on a comparison model (NULL)}

\item{CIs}{Whether to show Confidence intervals if they exist (TRUE)}

\item{zero.print}{How to show zeros (".")}

\item{report}{If "html", then open an html table of the results.}

\item{file}{The name of the dot file to write: NA = none; "name" = use the name of the model}

\item{returnStd}{Whether to return the standardized form of the model (default = FALSE)}

\item{extended}{How much to report (FALSE)}

\item{...}{Other parameters to control model summary}
}
\value{
\itemize{
\item optional \code{\link[=mxModel]{mxModel()}}
}
}
\description{
Summarize a Cholesky model with random-effects covariates, as returned by \code{\link[=umxACEcov]{umxACEcov()}}
}
\examples{
\dontrun{
require(umx)
data(twinData)
mzData = subset(twinData, zygosity == "MZFF")
dzData = subset(twinData, zygosity == "DZFF")
m1 = umxACEcov(selDVs = c("bmi", "wt"), selCovs = "ht", dzData = dzData, mzData = mzData, sep="")
umxSummaryACEcov(m1, file = NA)
umxSummaryACEcov(m1, file = "name", std = TRUE)
stdFit = umxSummary(m1, returnStd = TRUE)
}
}
\references{
\itemize{
\item \url{https://tbates.github.io},  \url{https://github.com/tbates/umx}
}
}
\seealso{
\itemize{
\item \code{\link[=umxACEcov]{umxACEcov()}}
}

Other Summary functions: 
\code{\link{umxSummary.MxModel}()},
\code{\link{umxSummaryCP}()},
\code{\link{umxSummaryGxE}()},
\code{\link{umxSummaryIP}()},
\code{\link{umxSummaryMRDoC}()}
}
\concept{Summary functions}
